@@ -12,7 +12,7 @@ SPVM_HASH* SPVM_HASH_new(int32_t table_capacity) {
   assert(table_capacity >= 0);
 
   // Create hash
-  SPVM_HASH* hash = SPVM_UTIL_ALLOCATOR_safe_malloc_i32(1, sizeof(SPVM_HASH));
+  SPVM_HASH* hash = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(1, sizeof(SPVM_HASH));
 
   // Default table capacity
   if (table_capacity == 0) {
@@ -23,17 +23,17 @@ SPVM_HASH* SPVM_HASH_new(int32_t table_capacity) {
   }
   
   // Initialize table
-  hash->table = SPVM_UTIL_ALLOCATOR_safe_malloc_i32(hash->table_capacity, sizeof(SPVM_HASH_ENTRY*));
+  hash->table = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(hash->table_capacity, sizeof(SPVM_HASH_ENTRY*));
   memset(hash->table, 0, hash->table_capacity * sizeof(SPVM_HASH_ENTRY*));
   
   // Initialize entries
   hash->entries_capacity = 255;
-  hash->entries = SPVM_UTIL_ALLOCATOR_safe_malloc_i32(hash->entries_capacity, sizeof(SPVM_HASH_ENTRY));
+  hash->entries = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(hash->entries_capacity, sizeof(SPVM_HASH_ENTRY));
   hash->entries_length = 0;
   
   // Initialize key buffer
   hash->key_buffer_capacity = 0xFF;
-  hash->key_buffer = SPVM_UTIL_ALLOCATOR_safe_malloc_i32(hash->key_buffer_capacity, sizeof(char));
+  hash->key_buffer = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(hash->key_buffer_capacity, sizeof(char));
   hash->key_buffer_length = 0;
   
   return hash;
@@ -51,7 +51,13 @@ void SPVM_HASH_maybe_extend_entries(SPVM_HASH* hash) {
   
   if (entries_length >= entries_capacity) {
     int32_t new_entries_capacity = entries_capacity * 2;
-    hash->entries = SPVM_UTIL_ALLOCATOR_safe_realloc_i32(hash->entries, new_entries_capacity, sizeof(SPVM_HASH_ENTRY));
+
+    SPVM_HASH_ENTRY* new_entries = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(new_entries_capacity, sizeof(SPVM_HASH_ENTRY));
+    memcpy(new_entries, hash->entries, entries_capacity * sizeof(SPVM_HASH_ENTRY));
+    // Free BSD segfault bug
+    // free(hash->entries);
+    hash->entries = new_entries;
+    
     hash->entries_capacity = new_entries_capacity;
   }
 }
@@ -68,7 +74,12 @@ void SPVM_HASH_maybe_extend_key_buffer(SPVM_HASH* hash, int32_t length) {
   
   if (key_buffer_length + length >= key_buffer_capacity) {
     int32_t new_key_buffer_capacity = key_buffer_capacity * 2;
-    hash->key_buffer = SPVM_UTIL_ALLOCATOR_safe_realloc_i32(hash->key_buffer, new_key_buffer_capacity, sizeof(SPVM_HASH_ENTRY));
+
+    char* new_key_buffer = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(new_key_buffer_capacity, sizeof(SPVM_HASH_ENTRY));
+    memcpy(new_key_buffer, hash->key_buffer, key_buffer_capacity);
+    free(hash->key_buffer);
+    hash->key_buffer = new_key_buffer;
+
     hash->key_buffer_capacity = new_key_buffer_capacity;
   }
 }
