@@ -45,7 +45,11 @@ void* SPVM_MEMORY_POOL_alloc(SPVM_MEMORY_POOL* memory_pool, int32_t byte_size) {
     if (memory_pool->current_page == memory_pool->pages_length) {
       int32_t new_memory_pool_pages_length = memory_pool->pages_length * 2;
       
-      memory_pool->pages = SPVM_UTIL_ALLOCATOR_safe_realloc_i32(memory_pool->pages, new_memory_pool_pages_length, sizeof(uint8_t*));
+      uint8_t** new_pages = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(new_memory_pool_pages_length, sizeof(uint8_t*));
+      memcpy(new_pages, memory_pool->pages, memory_pool->pages_length * sizeof(uint8_t*));
+      free(memory_pool->pages);
+      memory_pool->pages = new_pages;
+      
       {
         int32_t i;
         for (i = memory_pool->pages_length; i < new_memory_pool_pages_length; i++) {
