@@ -18,7 +18,7 @@
 #include "spvm_runtime_allocator.h"
 #include "spvm_api.h"
 
-void SPVM_RUNTIME_API_set_exception(SPVM_API* api, SPVM_SPVM_ARRAY* exception) {
+void SPVM_RUNTIME_API_set_exception(SPVM_API* api, SPVM_ARRAY* exception) {
   SPVM_RUNTIME* runtime = (SPVM_RUNTIME*)api->runtime;
   
   if (runtime->exception != NULL) {
@@ -32,22 +32,28 @@ void SPVM_RUNTIME_API_set_exception(SPVM_API* api, SPVM_SPVM_ARRAY* exception) {
   }
 }
 
-SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_byte_array_noinc(SPVM_API* api, int32_t length) {
+SPVM_ARRAY* SPVM_RUNTIME_API_get_exception(SPVM_API* api) {
+  SPVM_RUNTIME* runtime = (SPVM_RUNTIME*)api->runtime;
+  
+  return runtime->exception;
+}
+
+SPVM_ARRAY* SPVM_RUNTIME_API_malloc_byte_array_noinc(SPVM_API* api, int32_t length) {
   SPVM_RUNTIME* runtime = api->runtime;
   SPVM_RUNTIME_ALLOCATOR* allocator = runtime->allocator;
   
-  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_SPVM_ARRAY_C_VALUE_TYPE_BYTE);
+  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_ARRAY_C_VALUE_TYPE_BYTE);
   
   // Allocate array
-  int32_t array_byte_size = sizeof(SPVM_SPVM_ARRAY) + size * length;
-  SPVM_SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
+  int32_t array_byte_size = sizeof(SPVM_ARRAY) + size * length;
+  SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
   
   if (array) {
     // Set type
     array->type = SPVM_BASE_OBJECT_C_TYPE_ARRAY;
     
     // Set value type
-    array->value_type = SPVM_SPVM_ARRAY_C_VALUE_TYPE_BYTE;
+    array->value_type = SPVM_ARRAY_C_VALUE_TYPE_BYTE;
     
     // Set reference count
     array->ref_count = 0;
@@ -62,22 +68,22 @@ SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_byte_array_noinc(SPVM_API* api, int32_t
 }
 
 
-SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_short_array_noinc(SPVM_API* api, int32_t length) {
+SPVM_ARRAY* SPVM_RUNTIME_API_malloc_short_array_noinc(SPVM_API* api, int32_t length) {
   SPVM_RUNTIME* runtime = api->runtime;
   SPVM_RUNTIME_ALLOCATOR* allocator = runtime->allocator;
   
-  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_SPVM_ARRAY_C_VALUE_TYPE_SHORT);
+  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_ARRAY_C_VALUE_TYPE_SHORT);
   
   // Allocate array
-  int32_t array_byte_size = sizeof(SPVM_SPVM_ARRAY) + size * length;
-  SPVM_SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
+  int32_t array_byte_size = sizeof(SPVM_ARRAY) + size * length;
+  SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
   
   if (array) {
     // Set type
     array->type = SPVM_BASE_OBJECT_C_TYPE_ARRAY;
     
     // Set value type
-    array->value_type = SPVM_SPVM_ARRAY_C_VALUE_TYPE_SHORT;
+    array->value_type = SPVM_ARRAY_C_VALUE_TYPE_SHORT;
     
     // Set reference count
     array->ref_count = 0;
@@ -91,22 +97,22 @@ SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_short_array_noinc(SPVM_API* api, int32_
   return array;
 }
 
-SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_int_array_noinc(SPVM_API* api, int32_t length) {
+SPVM_ARRAY* SPVM_RUNTIME_API_malloc_int_array_noinc(SPVM_API* api, int32_t length) {
   SPVM_RUNTIME* runtime = api->runtime;
   SPVM_RUNTIME_ALLOCATOR* allocator = runtime->allocator;
   
-  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_SPVM_ARRAY_C_VALUE_TYPE_INT);
+  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_ARRAY_C_VALUE_TYPE_INT);
   
   // Allocate array
-  int32_t array_byte_size = sizeof(SPVM_SPVM_ARRAY) + size * length;
-  SPVM_SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
+  int32_t array_byte_size = sizeof(SPVM_ARRAY) + size * length;
+  SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
   
   if (array) {
     // Set type
     array->type = SPVM_BASE_OBJECT_C_TYPE_ARRAY;
     
     // Set value type
-    array->value_type = SPVM_SPVM_ARRAY_C_VALUE_TYPE_INT;
+    array->value_type = SPVM_ARRAY_C_VALUE_TYPE_INT;
     
     // Set reference count
     array->ref_count = 0;
@@ -120,22 +126,22 @@ SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_int_array_noinc(SPVM_API* api, int32_t
   return array;
 }
 
-SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_long_array_noinc(SPVM_API* api, int32_t length) {
+SPVM_ARRAY* SPVM_RUNTIME_API_malloc_long_array_noinc(SPVM_API* api, int32_t length) {
   SPVM_RUNTIME* runtime = api->runtime;
   SPVM_RUNTIME_ALLOCATOR* allocator = runtime->allocator;
   
-  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_SPVM_ARRAY_C_VALUE_TYPE_LONG);
+  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_ARRAY_C_VALUE_TYPE_LONG);
   
   // Allocate array
-  int32_t array_byte_size = sizeof(SPVM_SPVM_ARRAY) + size * length;
-  SPVM_SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
+  int32_t array_byte_size = sizeof(SPVM_ARRAY) + size * length;
+  SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
   
   if (array) {
     // Set type
     array->type = SPVM_BASE_OBJECT_C_TYPE_ARRAY;
     
     // Set value type
-    array->value_type = SPVM_SPVM_ARRAY_C_VALUE_TYPE_LONG;
+    array->value_type = SPVM_ARRAY_C_VALUE_TYPE_LONG;
     
     // Set reference count
     array->ref_count = 0;
@@ -149,22 +155,22 @@ SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_long_array_noinc(SPVM_API* api, int32_t
   return array;
 }
 
-SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_float_array_noinc(SPVM_API* api, int32_t length) {
+SPVM_ARRAY* SPVM_RUNTIME_API_malloc_float_array_noinc(SPVM_API* api, int32_t length) {
   SPVM_RUNTIME* runtime = api->runtime;
   SPVM_RUNTIME_ALLOCATOR* allocator = runtime->allocator;
   
-  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_SPVM_ARRAY_C_VALUE_TYPE_FLOAT);
+  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_ARRAY_C_VALUE_TYPE_FLOAT);
   
   // Allocate array
-  int32_t array_byte_size = sizeof(SPVM_SPVM_ARRAY) + size * length;
-  SPVM_SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
+  int32_t array_byte_size = sizeof(SPVM_ARRAY) + size * length;
+  SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
   
   if (array) {
     // Set type
     array->type = SPVM_BASE_OBJECT_C_TYPE_ARRAY;
     
     // Set value type
-    array->value_type = SPVM_SPVM_ARRAY_C_VALUE_TYPE_FLOAT;
+    array->value_type = SPVM_ARRAY_C_VALUE_TYPE_FLOAT;
     
     // Set reference count
     array->ref_count = 0;
@@ -178,22 +184,22 @@ SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_float_array_noinc(SPVM_API* api, int32_
   return array;
 }
 
-SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_double_array_noinc(SPVM_API* api, int32_t length) {
+SPVM_ARRAY* SPVM_RUNTIME_API_malloc_double_array_noinc(SPVM_API* api, int32_t length) {
   SPVM_RUNTIME* runtime = api->runtime;
   SPVM_RUNTIME_ALLOCATOR* allocator = runtime->allocator;
   
-  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_SPVM_ARRAY_C_VALUE_TYPE_DOUBLE);
+  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_ARRAY_C_VALUE_TYPE_DOUBLE);
   
   // Allocate array
-  int32_t array_byte_size = sizeof(SPVM_SPVM_ARRAY) + size * length;
-  SPVM_SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
+  int32_t array_byte_size = sizeof(SPVM_ARRAY) + size * length;
+  SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
   
   if (array) {
     // Set type
     array->type = SPVM_BASE_OBJECT_C_TYPE_ARRAY;
     
     // Set value type
-    array->value_type = SPVM_SPVM_ARRAY_C_VALUE_TYPE_DOUBLE;
+    array->value_type = SPVM_ARRAY_C_VALUE_TYPE_DOUBLE;
     
     // Set reference count
     array->ref_count = 0;
@@ -207,25 +213,25 @@ SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_double_array_noinc(SPVM_API* api, int32
   return array;
 }
 
-SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_malloc_object_array_noinc(SPVM_API* api, int32_t length) {
+SPVM_ARRAY* SPVM_RUNTIME_API_malloc_object_array_noinc(SPVM_API* api, int32_t length) {
   SPVM_RUNTIME* runtime = api->runtime;
   SPVM_RUNTIME_ALLOCATOR* allocator = runtime->allocator;
   
-  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_SPVM_ARRAY_C_VALUE_TYPE_OBJECT);
+  int32_t size = SPVM_RUNTIME_API_get_array_value_size(api, SPVM_ARRAY_C_VALUE_TYPE_OBJECT);
   
   // Allocate array
-  int32_t array_byte_size = sizeof(SPVM_SPVM_ARRAY) + size * length;
-  SPVM_SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
+  int32_t array_byte_size = sizeof(SPVM_ARRAY) + size * length;
+  SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
   
   if (array) {
     // Initialize by null
-    memset((void*)((intptr_t)array + sizeof(SPVM_SPVM_ARRAY)), 0, size * length);
+    memset((void*)((intptr_t)array + sizeof(SPVM_ARRAY)), 0, size * length);
     
     // Set type
     array->type = SPVM_BASE_OBJECT_C_TYPE_ARRAY;
     
     // Set value type
-    array->value_type = SPVM_SPVM_ARRAY_C_VALUE_TYPE_OBJECT;
+    array->value_type = SPVM_ARRAY_C_VALUE_TYPE_OBJECT;
     
     // Set reference count
     array->ref_count = 0;
@@ -273,52 +279,52 @@ SPVM_OBJECT* SPVM_RUNTIME_API_malloc_object_noinc(SPVM_API* api, int32_t package
   return object;
 }
 
-int32_t SPVM_RUNTIME_API_get_array_length(SPVM_API* api, SPVM_SPVM_ARRAY* array) {
+int32_t SPVM_RUNTIME_API_get_array_length(SPVM_API* api, SPVM_ARRAY* array) {
   (void)api;
   
   return array->length;
 }
 
-int8_t* SPVM_RUNTIME_API_get_byte_array_elements(SPVM_API* api, SPVM_SPVM_ARRAY* array) {
+int8_t* SPVM_RUNTIME_API_get_byte_array_elements(SPVM_API* api, SPVM_ARRAY* array) {
   (void)api;
 
-  return (int8_t*)((intptr_t)array + sizeof(SPVM_SPVM_ARRAY));
+  return (int8_t*)((intptr_t)array + sizeof(SPVM_ARRAY));
 }
 
-int16_t* SPVM_RUNTIME_API_get_short_array_elements(SPVM_API* api, SPVM_SPVM_ARRAY* array) {
+int16_t* SPVM_RUNTIME_API_get_short_array_elements(SPVM_API* api, SPVM_ARRAY* array) {
   (void)api;
   
-  return (int16_t*)((intptr_t)array + sizeof(SPVM_SPVM_ARRAY));
+  return (int16_t*)((intptr_t)array + sizeof(SPVM_ARRAY));
 }
 
-int32_t* SPVM_RUNTIME_API_get_int_array_elements(SPVM_API* api, SPVM_SPVM_ARRAY* array) {
+int32_t* SPVM_RUNTIME_API_get_int_array_elements(SPVM_API* api, SPVM_ARRAY* array) {
   (void)api;
   
-  return (int32_t*)((intptr_t)array + sizeof(SPVM_SPVM_ARRAY));
+  return (int32_t*)((intptr_t)array + sizeof(SPVM_ARRAY));
 }
 
-int64_t* SPVM_RUNTIME_API_get_long_array_elements(SPVM_API* api, SPVM_SPVM_ARRAY* array) {
+int64_t* SPVM_RUNTIME_API_get_long_array_elements(SPVM_API* api, SPVM_ARRAY* array) {
   (void)api;
   
-  return (int64_t*)((intptr_t)array + sizeof(SPVM_SPVM_ARRAY));
+  return (int64_t*)((intptr_t)array + sizeof(SPVM_ARRAY));
 }
 
-float* SPVM_RUNTIME_API_get_float_array_elements(SPVM_API* api, SPVM_SPVM_ARRAY* array) {
+float* SPVM_RUNTIME_API_get_float_array_elements(SPVM_API* api, SPVM_ARRAY* array) {
   (void)api;
   
-  return (float*)((intptr_t)array + sizeof(SPVM_SPVM_ARRAY));
+  return (float*)((intptr_t)array + sizeof(SPVM_ARRAY));
 }
 
-double* SPVM_RUNTIME_API_get_double_array_elements(SPVM_API* api, SPVM_SPVM_ARRAY* array) {
+double* SPVM_RUNTIME_API_get_double_array_elements(SPVM_API* api, SPVM_ARRAY* array) {
   (void)api;
   
-  return (double*)((intptr_t)array + sizeof(SPVM_SPVM_ARRAY));
+  return (double*)((intptr_t)array + sizeof(SPVM_ARRAY));
 }
 
-SPVM_BASE_OBJECT** SPVM_RUNTIME_API_get_object_array_elements(SPVM_API* api, SPVM_SPVM_ARRAY* array) {
+SPVM_BASE_OBJECT** SPVM_RUNTIME_API_get_object_array_elements(SPVM_API* api, SPVM_ARRAY* array) {
   (void)api;
   
-  return (SPVM_BASE_OBJECT**)((intptr_t)array + sizeof(SPVM_SPVM_ARRAY));
+  return (SPVM_BASE_OBJECT**)((intptr_t)array + sizeof(SPVM_ARRAY));
 }
 
 void SPVM_RUNTIME_API_dec_ref_count(SPVM_API* api, SPVM_BASE_OBJECT* base_object) {
@@ -334,8 +340,8 @@ void SPVM_RUNTIME_API_dec_ref_count(SPVM_API* api, SPVM_BASE_OBJECT* base_object
   if (base_object->ref_count == 0) {
     
     if (base_object->type == SPVM_BASE_OBJECT_C_TYPE_ARRAY) {
-      SPVM_SPVM_ARRAY* array = (SPVM_SPVM_ARRAY*)base_object;
-      if (array->value_type == SPVM_SPVM_ARRAY_C_VALUE_TYPE_OBJECT) {
+      SPVM_ARRAY* array = (SPVM_ARRAY*)base_object;
+      if (array->value_type == SPVM_ARRAY_C_VALUE_TYPE_OBJECT) {
         
         // Array length
         int32_t length = array->length;
@@ -600,7 +606,7 @@ void* SPVM_RUNTIME_API_get_var_object(SPVM_API* api, int32_t index) {
   return runtime->call_stack[runtime->call_stack_base + (size_t)index].object_value;
 }
 
-int32_t SPVM_RUNTIME_API_get_field_index(SPVM_API* api, SPVM_OBJECT* object, const char* name) {
+int32_t SPVM_RUNTIME_API_get_field_id(SPVM_API* api, SPVM_OBJECT* object, const char* name) {
   SPVM_RUNTIME* runtime = (SPVM_RUNTIME*)api->runtime;
   
   int32_t* constant_pool = runtime->constant_pool;
@@ -608,9 +614,11 @@ int32_t SPVM_RUNTIME_API_get_field_index(SPVM_API* api, SPVM_OBJECT* object, con
   memcpy(&constant_pool_package, &constant_pool[object->package_constant_pool_index], sizeof(SPVM_CONSTANT_POOL_PACKAGE));
   
   int32_t length = constant_pool_package.fields_length;
+  
+  
   int32_t field_indexes_constant_pool_index = constant_pool_package.field_indexes_constant_pool_index;
   
-  int32_t field_index = -1;
+  int32_t field_index = SPVM_API_ERROR_NO_ID;
   _Bool found = 0;
   {
     int32_t i;
@@ -622,7 +630,8 @@ int32_t SPVM_RUNTIME_API_get_field_index(SPVM_API* api, SPVM_OBJECT* object, con
       
       int32_t field_name_constant_pool_index = constant_pool_field.name_constant_pool_index;
       
-      char* match_name = (char*)&constant_pool[field_name_constant_pool_index];
+      char* match_name = (char*)&constant_pool[field_name_constant_pool_index + 1];
+      
       if (strcmp(name, match_name) == 0) {
         found = 1;
         field_index = i;
@@ -631,22 +640,17 @@ int32_t SPVM_RUNTIME_API_get_field_index(SPVM_API* api, SPVM_OBJECT* object, con
     }
   }
   
-  if (!found) {
-    fprintf(stderr, "Can't find field name \"%s\"\n", name);
-    abort();
-  }
-  
   return field_index;
 }
 
-int32_t SPVM_RUNTIME_API_get_sub_index(SPVM_API* api, const char* name) {
+int32_t SPVM_RUNTIME_API_get_sub_id(SPVM_API* api, const char* name) {
   SPVM_RUNTIME* runtime = (SPVM_RUNTIME*)api->runtime;
   
   int32_t* constant_pool = runtime->constant_pool;
   int32_t length = runtime->subs_length;
   int32_t sub_indexes_constant_pool_index = runtime-> sub_indexes_constant_pool_index;
   
-  int32_t found_sub_constant_pool_index = -1;
+  int32_t found_sub_constant_pool_index = SPVM_API_ERROR_NO_ID;
   _Bool found = 0;
   {
     int32_t i;
@@ -674,14 +678,14 @@ int32_t SPVM_RUNTIME_API_get_sub_index(SPVM_API* api, const char* name) {
   return found_sub_constant_pool_index;
 }
 
-int32_t SPVM_RUNTIME_API_get_package_index(SPVM_API* api, const char* name) {
+int32_t SPVM_RUNTIME_API_get_package_id(SPVM_API* api, const char* name) {
   SPVM_RUNTIME* runtime = (SPVM_RUNTIME*)api->runtime;
   
   int32_t* constant_pool = runtime->constant_pool;
   int32_t length = runtime->packages_length;
   int32_t package_indexes_constant_pool_index = runtime-> package_indexes_constant_pool_index;
   
-  int32_t found_package_constant_pool_index = -1;
+  int32_t found_package_constant_pool_index = SPVM_API_ERROR_NO_ID;
   _Bool found = 0;
   {
     int32_t i;
@@ -818,8 +822,8 @@ int64_t SPVM_RUNTIME_API_calcurate_base_object_byte_size(SPVM_API* api, SPVM_BAS
   
   // Reference is string
   if (base_object->type == SPVM_BASE_OBJECT_C_TYPE_ARRAY) {
-    SPVM_SPVM_ARRAY* array = (SPVM_SPVM_ARRAY*)base_object;
-    byte_size = sizeof(SPVM_SPVM_ARRAY) + array->length * SPVM_RUNTIME_API_get_array_value_size(api, array->value_type);
+    SPVM_ARRAY* array = (SPVM_ARRAY*)base_object;
+    byte_size = sizeof(SPVM_ARRAY) + array->length * SPVM_RUNTIME_API_get_array_value_size(api, array->value_type);
   }
   // Reference is object
   else if (base_object->type == SPVM_BASE_OBJECT_C_TYPE_OBJECT) {
@@ -835,14 +839,14 @@ int64_t SPVM_RUNTIME_API_calcurate_base_object_byte_size(SPVM_API* api, SPVM_BAS
   return byte_size;
 }
 
-SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_create_array_byte(SPVM_API* api, int32_t length) {
+SPVM_ARRAY* SPVM_RUNTIME_API_create_array_byte(SPVM_API* api, int32_t length) {
   SPVM_RUNTIME* runtime = (SPVM_RUNTIME*)api->runtime;
   
   SPVM_RUNTIME_ALLOCATOR* allocator = runtime->allocator;
   
   // Allocate array
-  int32_t array_byte_size = sizeof(SPVM_SPVM_ARRAY) + sizeof(int8_t) * length;
-  SPVM_SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
+  int32_t array_byte_size = sizeof(SPVM_ARRAY) + sizeof(int8_t) * length;
+  SPVM_ARRAY* array = SPVM_RUNTIME_ALLOCATOR_malloc(api, allocator, array_byte_size);
   
   // Fatal memory allocation error
   if (!array) {
@@ -854,7 +858,7 @@ SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_create_array_byte(SPVM_API* api, int32_t lengt
   array->type = SPVM_BASE_OBJECT_C_TYPE_ARRAY;
   
   // Set sub type
-  array->value_type = SPVM_SPVM_ARRAY_C_VALUE_TYPE_BYTE;
+  array->value_type = SPVM_ARRAY_C_VALUE_TYPE_BYTE;
   
   // Set reference count
   array->ref_count = 0;
@@ -867,14 +871,14 @@ SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_create_array_byte(SPVM_API* api, int32_t lengt
   return array;
 }
 
-SPVM_SPVM_ARRAY* SPVM_RUNTIME_API_create_array_byte_from_pv(SPVM_API* api, const char* pv) {
+SPVM_ARRAY* SPVM_RUNTIME_API_create_array_byte_from_pv(SPVM_API* api, const char* pv) {
   (void)api;
   
   int32_t length = strlen(pv);
-  SPVM_SPVM_ARRAY* array = SPVM_RUNTIME_API_create_array_byte(api, length);
+  SPVM_ARRAY* array = SPVM_RUNTIME_API_create_array_byte(api, length);
   
   // Copy string
-  memcpy((void*)((intptr_t)array + sizeof(SPVM_SPVM_ARRAY)), pv, length);
+  memcpy((void*)((intptr_t)array + sizeof(SPVM_ARRAY)), pv, length);
   
   return array;
 }
